%global srcname ufc
%global majorver 2
%global minorver 1
%global pointver 0

Name:		python-%{srcname}
Version:	%{majorver}.%{minorver}.%{pointver}
Release:	8%{?dist}
Summary:	A unified framework for finite element assembly
Group:		Applications/Engineering

License:	Public Domain and LGPLv2 and GPLv2+

URL:		http://fenicsproject.org
Source0:	https://launchpad.net/%{srcname}/%{majorver}.%{minorver}.x/%{version}/+download/%{srcname}-%{version}.tar.gz

# Fix lib install path (required by pkg-config file)
# Reported upstream as https://bugs.launchpad.net/bugs/1104179
Patch0:         ufc-2.0.5-fix-lib-path.patch

BuildRoot:	%{_tmppath}/%{srcname}-%{version}-%{release}-root-%(%{__id_u} -n)

Requires: 	swig

%if (0%{?rhel} <= 6 && !0%{?fedora})
BuildRequires:	cmake28
%else
BuildRequires:	cmake
%endif
BuildRequires: 	swig
BuildRequires:	boost-devel
BuildRequires: 	python2-devel
BuildRequires:  ghostscript

BuildRequires:  tex(latex)
%if (0%{?rhel} && 0%{?rhel} >= 7) || (0%{?fedora} && 0%{?fedora} >= 18)
BuildRequires:  texlive-collection-latexextra
BuildRequires:  texlive-collection-fontsextra
%endif


%description
UFC (Unified Form-assembly Code) is a unified framework for finite
element assembly. More precisely, it defines a fixed interface for
communicating low level routines (functions) for evaluating and
assembling finite element variational forms. The UFC interface
consists of a single header file ufc.h that specifies a C++ interface
that must be implemented by code that complies with the UFC
specification.

%prep
%setup -q -n %{srcname}-%{version}
%patch0 -p0 -b .fix-lib-path

%build
%if (0%{?rhel} <= 6 && !0%{?fedora})
%cmake28 .
%else
%cmake .
%endif

make %{?_smp_mflags}

# Build the documentation
# Disabled presently due to a problem with ghostscript not finding the tex fonts when pdf2ps is run.
pushd doc/manual
make final
popd

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT

# Fix permissions on _ufc.so so that it is properly stripped (BZ 904845)
chmod +x $RPM_BUILD_ROOT%{python_sitearch}/ufc/*.so

%clean
rm -rf $RPM_BUILD_ROOT


%files
%defattr(-,root,root,-)
%doc README AUTHORS TODO COPYING.LGPL COPYING.GPL-2 LICENSE ChangeLog 
#doc doc/manual/ufc-user-manual.pdf doc/sphinx
%{_includedir}/ufc.h
%{_libdir}/pkgconfig/ufc-1.pc
%{python_sitelib}/ufc_utils
%{python_sitearch}/ufc
%{_datadir}/ufc
%{_includedir}/swig/ufc.i

%changelog
* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.0-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 23 2014 Petr Machata <pmachata@redhat.com> - 2.1.0-6
- Rebuild for boost 1.55.0

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jul 30 2013 Petr Machata <pmachata@redhat.com> - 2.1.0-4
- Rebuild for boost 1.54.0

* Mon Jan 28 2013 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 2.1.0-3
- Fix permissions on _ufc.so so that it is properly stripped (BZ #904845)

* Fri Jan 25 2013 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 2.1.0-2
- Add a BuildRequires for texlive-collection-fontsextra to allow docs
  to build

* Thu Jan 24 2013 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 2.1.0-1
- Update to version 2.1.0
- Disable doc building due to a problem with ghostscript and tex fonts

* Thu Jan 24 2013 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 2.0.5-0.3
- Fix texlive BuildRequires for Fedora >= 18
- Add needed BuildRequires for ghostscript (pdf2ps)
- Fix BuildRequires for python2-devel

* Mon Oct  1 2012 José Matos <jamatos@fedoraproject.org> - 2.0.5-0.2
- Fix conditionals for Fedora
- Fix path for pkgconfig file

* Fri May  4 2012 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 2.0.5-0.1
- Initial package

